<?php

namespace Softwaretantra\Iksc\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Softwaretantra\Iksc\Http\Requests\TestikscRequest;
use Softwaretantra\Iksc\Interfaces\TestikscRepositoryInterface;
use Softwaretantra\Iksc\Models\Testiksc;

/**
 * Resource controller class for testiksc.
 */
class TestikscResourceController extends BaseController
{

    /**
     * Initialize testiksc resource controller.
     *
     * @param type TestikscRepositoryInterface $testiksc
     *
     * @return null
     */
    public function __construct(TestikscRepositoryInterface $testiksc)
    {
        parent::__construct();
        $this->repository = $testiksc;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Softwaretantra\Iksc\Repositories\Criteria\TestikscResourceCriteria::class);
    }

    /**
     * Display a list of testiksc.
     *
     * @return Response
     */
    public function index(TestikscRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Softwaretantra\Iksc\Repositories\Presenter\TestikscPresenter::class)
                ->$function();
        }

        $testikscs = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('iksc::testiksc.names'))
            ->view('iksc::testiksc.index', true)
            ->data(compact('testikscs', 'view'))
            ->output();
    }

    /**
     * Display testiksc.
     *
     * @param Request $request
     * @param Model   $testiksc
     *
     * @return Response
     */
    public function show(TestikscRequest $request, Testiksc $testiksc)
    {

        if ($testiksc->exists) {
            $view = 'iksc::testiksc.show';
        } else {
            $view = 'iksc::testiksc.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('iksc::testiksc.name'))
            ->data(compact('testiksc'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new testiksc.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TestikscRequest $request)
    {

        $testiksc = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('iksc::testiksc.name')) 
            ->view('iksc::testiksc.create', true) 
            ->data(compact('testiksc'))
            ->output();
    }

    /**
     * Create new testiksc.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TestikscRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $testiksc                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('iksc::testiksc.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('iksc/testiksc/' . $testiksc->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/iksc/testiksc'))
                ->redirect();
        }

    }

    /**
     * Show testiksc for editing.
     *
     * @param Request $request
     * @param Model   $testiksc
     *
     * @return Response
     */
    public function edit(TestikscRequest $request, Testiksc $testiksc)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('iksc::testiksc.name'))
            ->view('iksc::testiksc.edit', true)
            ->data(compact('testiksc'))
            ->output();
    }

    /**
     * Update the testiksc.
     *
     * @param Request $request
     * @param Model   $testiksc
     *
     * @return Response
     */
    public function update(TestikscRequest $request, Testiksc $testiksc)
    {
        try {
            $attributes = $request->all();

            $testiksc->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('iksc::testiksc.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('iksc/testiksc/' . $testiksc->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('iksc/testiksc/' . $testiksc->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the testiksc.
     *
     * @param Model   $testiksc
     *
     * @return Response
     */
    public function destroy(TestikscRequest $request, Testiksc $testiksc)
    {
        try {

            $testiksc->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('iksc::testiksc.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('iksc/testiksc/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('iksc/testiksc/' . $testiksc->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple testiksc.
     *
     * @param Model   $testiksc
     *
     * @return Response
     */
    public function delete(TestikscRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('iksc::testiksc.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('iksc/testiksc'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/iksc/testiksc'))
                ->redirect();
        }

    }

    /**
     * Restore deleted testikscs.
     *
     * @param Model   $testiksc
     *
     * @return Response
     */
    public function restore(TestikscRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('iksc::testiksc.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/iksc/testiksc'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/iksc/testiksc/'))
                ->redirect();
        }

    }

}
