<?php

namespace Softwaretantra\Iksc\Workflow;

use Softwaretantra\Iksc\Models\Testiksc;
use Validator;

class TestikscValidator
{

    /**
     * Determine if the given testiksc is valid for complete status.
     *
     * @param Testiksc $testiksc
     *
     * @return bool / Validator
     */
    public function complete(Testiksc $testiksc)
    {
        return Validator::make($testiksc->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given testiksc is valid for verify status.
     *
     * @param Testiksc $testiksc
     *
     * @return bool / Validator
     */
    public function verify(Testiksc $testiksc)
    {
        return Validator::make($testiksc->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given testiksc is valid for approve status.
     *
     * @param Testiksc $testiksc
     *
     * @return bool / Validator
     */
    public function approve(Testiksc $testiksc)
    {
        return Validator::make($testiksc->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given testiksc is valid for publish status.
     *
     * @param Testiksc $testiksc
     *
     * @return bool / Validator
     */
    public function publish(Testiksc $testiksc)
    {
        return Validator::make($testiksc->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given testiksc is valid for archive status.
     *
     * @param Testiksc $testiksc
     *
     * @return bool / Validator
     */
    public function archive(Testiksc $testiksc)
    {
        return Validator::make($testiksc->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given testiksc is valid for unpublish status.
     *
     * @param Testiksc $testiksc
     *
     * @return bool / Validator
     */
    public function unpublish(Testiksc $testiksc)
    {
        return Validator::make($testiksc->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
